@@ -3,7 +3,7 @@ check.RS <- function(io){
   if(!"InputOutput" %in% class(io)) stop('io should be of "InputOutput" class. See ?as.inputoutput')
   RS_label <- io$RS_label
   regions <- unique(RS_label[, 1])
-  RS.1 <- RS_label[RS_label[, 1] == regions[1],]
+  RS.1 <- matrix(c(RS_label[RS_label[, 1] == regions[1],]), ncol = 2)
   the.same <- "yes"
   for(r in 2:length(regions)){
     i <- which(RS_label[, 1] == regions[r])
