@@ -4,15 +4,15 @@ import.total <- function(io){
   RS_label <- io$RS_label
   regions <- unique(RS_label[, 1])
   # Getting to work
-  import <- rep(NA, dim(Z)[1])
-  if(!exists("io$M") & length(regions) == 1) stop("There is only one region and no imports. Check io$M")
+  import <- matrix(0, ncol = dim(Z)[1])
+  if(is.null(io$M) & length(regions) == 1) stop("There is only one region and no imports. Check io$M")
   check <- 0
-  if(exists("io$M")){
+  if(!is.null(io$M)){
     check <- 1
     M <- io$M
-    if(dim(M)[2] > 1){
-      one <- matrix(rep(1, dim(M)[2]))
-      M <- M %*% one
+    if(dim(M)[1] > 1){
+      one <- matrix(rep(1, dim(1)[2]))
+      M <- t(one) %*% M
     }
   } else if(length(regions) > 1){
     for(r in 1:length(regions)){
